@@ -6,7 +6,7 @@ import uuid
 import pickle
 import sys
 
-from bravado.exception import HTTPBadGateway, HTTPUnauthorized, HTTPBadRequest, HTTPNotFound, HTTPGatewayTimeout, HTTPServiceUnavailable
+from bravado.exception import HTTPBadGateway, HTTPUnauthorized, HTTPBadRequest, HTTPNotFound, HTTPGatewayTimeout, HTTPServiceUnavailable, HTTPTooManyRequests
 
 
 class BitmexClient:
@@ -84,6 +84,25 @@ class BitmexClient:
             #     pass
             return self.last_current_price(symbol)
 
+    def get_current_price_candle(self, symbol):
+        try:
+            price = self.client.Trade.Trade_getBucketed(symbol=symbol,
+                                                        binSize='1m',
+                                                        count=1,
+                                                        reverse=True,
+                                                        ).result()[0][0]
+            return price
+        except (IndexError, HTTPBadRequest, HTTPBadGateway, HTTPGatewayTimeout, HTTPServiceUnavailable, HTTPTooManyRequests) as e:
+            if 'Service Unavailable' in str(e):
+                print(
+                    'Server maintenance. Trying to reconnect in 5 Minutes...', flush=True)
+                while True:
+                    time.sleep(360)
+                    current_price = self.get_current_price(symbol)
+                    if current_price:
+                        break
+            return self._last_currentprice[symbol]
+
     def last_current_price(self, symbol):
         if symbol in self._last_currentprice.keys():
             return self._last_currentprice[symbol]
@@ -125,6 +144,7 @@ class BitmexOrder:
         self.settings = settings
         self._settings_path = settings_path
         self.magic = magic
+        self._symbols = symbols
 
         self.props = {}
         for symbol in symbols:
@@ -175,9 +195,10 @@ class BitmexOrder:
         else:
             print("No Stop Type given.")
 
-    def manage_entries(self, symbols):
+    def manage_entries(self, symbols, me_count, cp=''):
         for symbol in symbols:
-            cp = self.client.get_current_price(symbol)
+            if not cp:
+                cp = self.client.get_current_price(symbol)
             if self.props[symbol]['wait_stop']:
                 time.sleep(0.5)
                 if self.props[symbol]['qty'] > 0 and cp >= self.props[symbol]['entry'] and self.client.open_contracts(symbol) != 0:
@@ -203,6 +224,15 @@ class BitmexOrder:
                     print("Short Position {} closed. {} Contracts from {} to {}. PnL in Points: {}".format(symbol,
                                                                                                            -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, self.props[symbol]['entry']-self.props[symbol]['SL'])), flush=True)
                     self.props[symbol]['qty'] = 0
+         # every 3rd time also check the minute high/low (10 second window can miss executions sometimes)
+        if me_count % 3 == 0:
+            time.sleep(5)  # don't execute at same time like 'cp'
+            if self.props[symbol]['qty'] > 0:
+                cp = self.client.get_current_price_candle(symbol)['high']
+                self.manage_entries(self._symbols, me_count+1, cp=cp)
+            elif self.props[symbol]['qty'] < 0:
+                cp = self.client.get_current_price_candle(symbol)['low']
+                self.manage_entries(self._symbols, me_count+1, cp=cp)
 
     def generate_id(self, symbol, _type='stop'):
         return "{}_{}_{}_{}".format(self.magic, symbol, str(uuid.uuid4().fields[-1])[:5], _type)
