@@ -11,6 +11,7 @@ import sys
 
 from socket import gaierror
 
+
 class Lotus:
     def __init__(self, client, symbols, settings, setting_file_name):
         self.client = client
@@ -31,6 +32,8 @@ class Lotus:
         self._last_entry = {}
         self._last_sl = {}
 
+        self.me_count = 0  # initialize manage entries count for candle check every 3rd time
+
         signal.signal(signal.SIGINT, self.signal_handler)
 
         for symbol in symbols:
@@ -77,7 +80,8 @@ class Lotus:
             print('Retrying connection to endpoint')
             return self.get_api_signal()
         except requests.exceptions.TooManyRedirects:
-            print('Bad URL. Try to setup the correct endpoint. Current endpoint: {}'.format(self._api_endpoint))
+            print('Bad URL. Try to setup the correct endpoint. Current endpoint: {}'.format(
+                self._api_endpoint))
             return False
         except requests.exceptions.RequestException as e:
             print('Another exception occured {}'.format(e))
@@ -195,7 +199,7 @@ class Lotus:
                             self.order.bracket_stop_order(
                                 symbol, -contracts, entry, stoploss)
                     else:
-                        if self.order.props[symbol]['open']:
+                        if self.order.props[symbol]['open'] or self.client.open_contracts(symbol) > 0:
                             self.order.close(symbol)
             elif signal != 0:
                 self.manage_open_stop_orders(symbol)
@@ -217,11 +221,12 @@ class Lotus:
                 break
         while True:
             time.sleep(10)
-            self.order.manage_entries(self.symbols)
-            if datetime.datetime.utcnow().minute % 30 == 0:
-                second = datetime.datetime.utcnow().second
-                time.sleep(second + 19 - second +
-                           self.rand_sec(start=1, end=3))
+            self.me_count += 1
+            self.order.manage_entries(self.symbols, self.me_count)
+            now = datetime.datetime.utcnow()
+            if now.minute % 30 == 0:
+                exec_minute = now.minute
+                time.sleep(19 + self.rand_sec(start=1, end=3))
                 count_s_tries = 0
                 while True:
                     signal = self.get_api_signal()
@@ -234,8 +239,11 @@ class Lotus:
                         break
                     count_s_tries += 1
                     if count_s_tries > 15:
-                        print('Signal is offline', flush=True)
+                        print('No new signal.', flush=True)
                         break
                     time.sleep(self.rand_sec())
-
-                time.sleep(40)
+                while True:
+                    time.sleep(10)
+                    self.order.manage_entries(self.symbols)
+                    if datetime.datetime.utcnow().minute != exec_minute:
+                        break
